@@ -154,6 +154,7 @@ import httplib2
 import datetime
 import time
 from pathlib import Path
+from html import escape
 
 try:
     from googleapiclient import discovery
@@ -276,7 +277,7 @@ class Py3status:
 
         Returns: The list of events.
         """
-        self.last_update = time.perf_counter()
+        self.last_update = time.monotonic()
         time_min = datetime.datetime.utcnow()
         time_max = time_min + datetime.timedelta(hours=self.events_within_hours)
         events = []
@@ -411,7 +412,7 @@ class Py3status:
 
             event_dict = {}
 
-            event_dict["summary"] = event.get("summary")
+            event_dict["summary"] = escape(event.get("summary"))
             event_dict["location"] = event.get("location")
             event_dict["description"] = event.get("description")
             self.event_urls.append(
@@ -520,7 +521,7 @@ class Py3status:
                 self.py3.prevent_refresh()
             elif button == self.button_refresh:
                 # wait before the next refresh
-                if time.perf_counter() - self.last_update > 1:
+                if time.monotonic() - self.last_update > 1:
                     self.no_update = False
             elif button == self.button_toggle:
                 self.button_states[button_index] = not self.button_states[button_index]
