@@ -20,12 +20,9 @@ Configuration parameters:
         (default 'Pomodoro ({format})')
     num_progress_bars: number of progress bars (default 5)
     pomodoros: specify a number of pomodoros (intervals) (default 4)
-    sound_break_end: break end sound (file path) (requires pyglet
-        or pygame) (default None)
-    sound_pomodoro_end: pomodoro end sound (file path) (requires pyglet
-        or pygame) (default None)
-    sound_pomodoro_start: pomodoro start sound (file path) (requires pyglet
-        or pygame) (default None)
+    sound_break_end: break end sound (file path) (default None)
+    sound_pomodoro_end: pomodoro end sound (file path) (default None)
+    sound_pomodoro_start: pomodoro start sound (file path) (default None)
     timer_break: normal break time (seconds) (default 300)
     timer_long_break: long break time (seconds) (default 900)
     timer_pomodoro: pomodoro time (seconds) (default 1500)
@@ -58,9 +55,10 @@ running
 {'color': '#00FF00', 'full_text': u'Pomodoro [1483]'}
 """
 
+import time
 from math import ceil
 from threading import Timer
-from time import time
+
 
 PROGRESS_BAR_ITEMS = "▏▎▍▌▋▊▉"
 
@@ -117,7 +115,7 @@ class Py3status:
         if self._active:
             self.py3.notify_user("Pomodoro time is up !")
         else:
-            self.py3.notify_user("Break #{} time is up !".format(self._break_number))
+            self.py3.notify_user(f"Break #{self._break_number} time is up !")
         self._alert = True
         self._advance()
 
@@ -160,12 +158,12 @@ class Py3status:
         if event["button"] == 1:
             if self._running:
                 self._running = False
-                self._time_left = self._end_time - time()
+                self._time_left = self._end_time - time.monotonic()
                 if self._timer:
                     self._timer.cancel()
             else:
                 self._running = True
-                self._end_time = time() + self._time_left
+                self._end_time = time.monotonic() + self._time_left
                 if self._timer:
                     self._timer.cancel()
                 self._timer = Timer(self._time_left, self._time_up)
@@ -191,10 +189,9 @@ class Py3status:
         """
         bar = ""
         items_cnt = len(PROGRESS_BAR_ITEMS)
-        bar_val = float(self._time_left) / self._section_time * self.num_progress_bars
+        bar_val = self._time_left / self._section_time * self.num_progress_bars
         while bar_val > 0:
-            selector = int(bar_val * items_cnt)
-            selector = min(selector, items_cnt - 1)
+            selector = min(int(bar_val * items_cnt), items_cnt - 1)
             bar += PROGRESS_BAR_ITEMS[selector]
             bar_val -= 1
 
@@ -210,27 +207,24 @@ class Py3status:
 
         cached_until = self.py3.time_in(0)
         if self._running:
-            self._time_left = ceil(self._end_time - time())
+            self._time_left = ceil(self._end_time - time.monotonic())
             time_left = ceil(self._time_left)
         else:
             time_left = ceil(self._time_left)
 
-        vals = {"ss": int(time_left), "mm": int(ceil(time_left / 60))}
+        vals = {"ss": int(time_left), "mm": ceil(time_left / 60)}
 
         if self.py3.format_contains(self.format, "mmss"):
             hours, rest = divmod(time_left, 3600)
             mins, seconds = divmod(rest, 60)
 
             if hours:
-                vals["mmss"] = "%d%s%02d%s%02d" % (
-                    hours,
-                    self.format_separator,
-                    mins,
-                    self.format_separator,
-                    seconds,
+                vals["mmss"] = (
+                    f"{hours}{self.format_separator}"
+                    f"{mins:02d}{self.format_separator}{seconds:02d}"
                 )
             else:
-                vals["mmss"] = "%d%s%02d" % (mins, self.format_separator, seconds)
+                vals["mmss"] = f"{mins}{self.format_separator}{seconds:02d}"
 
         if self.py3.format_contains(self.format, "bar"):
             vals["bar"] = self._setup_bar()
