@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Add color cycling fun to your i3bar.
 
@@ -66,10 +65,9 @@ SAMPLE OUTPUT
 ]
 """
 
-from __future__ import division
 import re
 import math
-from time import time
+import time
 
 HEX_RE = re.compile("#([0-9a-fA-F]{3}|[0-9a-fA-F]{6})")
 
@@ -140,15 +138,9 @@ class Py3status:
         if self.steps == 1:
             colors = [to_hex(from_hex(x)) for x in self.gradient]
         else:
-            for i in range(len(self.gradient) - 1):
+            for grad_a, grad_b in zip(self.gradient, self.gradient[1:]):
                 for j in range(self.steps):
-                    colors.append(
-                        to_hex(
-                            make_color(
-                                self.gradient[i], self.gradient[i + 1], j / (self.steps)
-                            )
-                        )
-                    )
+                    colors.append(to_hex(make_color(grad_a, grad_b, j / self.steps)))
         self.colors = colors
         self.active_color = 0
         self._set_cycle_time()
@@ -157,7 +149,7 @@ class Py3status:
         """
         Set next cycle update time synced to nearest second or 0.1 of second.
         """
-        now = time()
+        now = time.monotonic()
         try:
             cycle_time = now - self._cycle_time
             if cycle_time < 0:
@@ -190,7 +182,7 @@ class Py3status:
         if not self.items:
             return {"full_text": "", "cached_until": self.py3.CACHE_FOREVER}
 
-        if time() >= self._cycle_time - (self.cycle_time / 10):
+        if time.monotonic() >= self._cycle_time - (self.cycle_time / 10):
             self.active_color = (self.active_color + 1) % len(self.colors)
             self._set_cycle_time()
 
