@@ -99,7 +99,7 @@ class Py3status:
                 color = self.color_open
                 state = self.state_open
 
-            if "lastchange" in data["state"].keys():
+            if "lastchange" in data["state"]:
                 try:
                     dt = datetime.datetime.fromtimestamp(data["state"]["lastchange"])
                     lastchanged = dt.strftime(self.format_lastchanged)
@@ -126,7 +126,7 @@ class Py3status:
         button = event["button"]
         if button == self.button_url:
             if self.hackerspace_url:
-                self.py3.command_run("xdg-open {}".format(self.hackerspace_url))
+                self.py3.command_run(f"xdg-open {self.hackerspace_url}")
         if button != self.button_refresh:
             self.py3.prevent_refresh()
 
