@@ -119,6 +119,7 @@ class Amixer(Audio):
             self.device = "default"
         self.cmd = [
             "amixer",
+            "-M",
             "-q",
             "-c",
             self.card,
@@ -199,6 +200,7 @@ class Pamixer(Audio):
 class Pactl(Audio):
     def setup(self, parent):
         # get available device number if not specified
+        self.detected_devices = {}
         self.device_type = "source" if self.is_input else "sink"
         self.device_type_pl = self.device_type + "s"
         self.device_type_cap = self.device_type[0].upper() + self.device_type[1:]
@@ -263,7 +265,9 @@ class Pactl(Audio):
             if len(parts) < 2:
                 continue
             current_devices[parts[0]] = parts[1]
-        # self.parent.py3.log(f"available {self.device_type_pl}: {current_devices}")
+        if current_devices != self.detected_devices:
+            self.detected_devices = current_devices
+            self.parent.py3.log(f"available {self.device_type_pl}: {current_devices}")
         return current_devices
 
     def get_volume(self):
@@ -352,7 +356,7 @@ class Py3status:
         if not self.command:
             commands = ["pamixer", "pactl", "amixer"]
             # pamixer, pactl requires pulseaudio to work
-            if not self.py3.check_commands("pulseaudio"):
+            if not self.py3.check_commands(["pulseaudio", "pipewire"]):
                 commands = ["amixer"]
             self.command = self.py3.check_commands(commands)
         elif self.command not in ["amixer", "pamixer", "pactl"]:
